@@ -4,10 +4,10 @@ use cargo2port::{format_cargo_crates, read_packages_from_lockfiles, AlignmentMod
 use goldenfile::Mint;
 
 fn lockfiles() -> Vec<String> {
-    return vec![
+    vec![
         "tests/support/multi_lockfile_one".to_string(),
         "tests/support/multi_lockfile_two".to_string(),
-    ];
+    ]
 }
 
 #[test]
@@ -42,3 +42,14 @@ fn test_multi_file_multiline_mode() {
 
     writeln!(file, "{}", output).unwrap();
 }
+
+#[test]
+fn test_multi_file_justify_mode() {
+    let mut mint = Mint::new("tests/support");
+    let mut file = mint.new_goldenfile("multi_file_justify").unwrap();
+
+    let packages = read_packages_from_lockfiles(&lockfiles()).unwrap();
+    let output = format_cargo_crates(packages, AlignmentMode::Justify);
+
+    writeln!(file, "{}", output).unwrap();
+}
